@@ -21,19 +21,19 @@ from pathlib import Path
 from shutil import which
 from textwrap import dedent, indent, shorten
 
-import click
 from boltons.cacheutils import cachedproperty
 from boltons.iterutils import flatten
 from boltons.strutils import strip_ansi
 from boltons.typeutils import classproperty
+from click_extra.colorize import theme
+from click_extra.logging import logger
+from click_extra.platform import CURRENT_OS_ID
+from click_extra.run import INDENT, PROMPT, run
 
-from . import INDENT, PROMPT, logger
-from .platform import CURRENT_OS_ID
 from .version import parse_version
-from .xbar import run
 
-# Rendering format of CLI in JSON fields.
-CLI_FORMATS = frozenset(["plain", "fragments", "xbar"])
+CLI_FORMATS = frozenset({"plain", "fragments", "xbar"})
+"""Rendering format of CLI in JSON fields."""
 
 
 class CLIError(Exception):
@@ -72,42 +72,56 @@ class CLIError(Exception):
 
 class PackageManager:
 
-    """Base class from which all package manager definitions must inherits."""
+    """Base class from which all package manager definitions inherits."""
 
-    # List of platforms supported by the manager.
     platforms = frozenset()
+    """List of platforms supported by the manager."""
 
-    # Version requirement specifier.
     requirement = None
+    """Minimal required version."""
 
-    # List of options to use to get the version from the package manager.
-    version_cli_options = ["--version"]
+    version_cli_options = ("--version",)
+    """List of options to get the version from the package manager CLI."""
 
-    # Regular expression used to extract the version number from the result of the CLI
-    # run with the options above. It doesn't matter if the regex returns unsanitized
-    # and crappy string. The ``version()`` method will clean and normalized it.
-    # By default match the first part that is space-separated.
     version_regex = r"(?P<version>\S+)"
+    """ Regular expression used to extract the version number from the result of the CLI
+    run with the options above. It doesn't matter if the regex returns unsanitized
+    and crappy string. The ``version()`` method will clean and normalized it.
 
-    # List of additional path to help mpm hunt down the package manager CLI.
-    # Should be a list of strings whose order dictatate the search sequence.
-    # Most of the time unnecessay: the `cli_path()` method works well on all
-    # platforms.
-    cli_search_path = []
+    By default match the first part that is space-separated.
+    """
 
-    # Global list of options used for each call to the package manager CLI.
-    # Might be of use to force silencing or high verbosity.
-    global_args = []
+    cli_search_path = ()
+    """ List of additional path to help mpm hunt down the package manager CLI.
+
+    Should be a list of strings whose order dictatate the search sequence.
+
+    Most of the time unnecessay: :py:func:`meta_package_manager.base.PackageManager.cli_path`
+    works well on all platforms.
+    """
+
+    global_args = ()
+    """Global list of options used for each call to the package manager CLI.
+
+    Automaticcaly added to each :py:func:`meta_package_manager.base.PackageManager.run_cli`
+    call.
+
+    Usually used to force silencing, low verbosity or no color output.
+    """
+
+    prepend_global_args = True
+    """Add the global args either at the begginning (``True``) or the end (``False``) of the CLI.
+    """
 
-    # Tell the manager either to raise or continue on errors.
     stop_on_error = False
+    """Tell the manager to either raise or continue on errors."""
 
-    # Some managers have the ability to report or ignore packages
-    # possessing their own auto-update mecanism.
     ignore_auto_updates = True
+    """Some managers can report or ignore packages which have their own auto-update mecanism.
+    """
 
-    # Do not actually perform any action, just simulate CLI calls.
     dry_run = False
+    """Do not actually perform any action, just simulate CLI calls."""
 
     def __init__(self):
         # Log of all encountered CLI errors.
@@ -137,7 +151,7 @@ class PackageManager:
 
         Is derived by default from the manager's ID.
         """
-        return [cls.id]
+        return (cls.id,)
 
     @classproperty
     def virtual(cls):
@@ -161,7 +175,7 @@ class PackageManager:
         Returns ``None`` if no CLI was found or those found were not a file.
         """
         # Check if the path exist in any of the environment locations.
-        env_path = ":".join(self.cli_search_path + [os.getenv("PATH")])
+        env_path = ":".join(flatten((self.cli_search_path, os.getenv("PATH"))))
 
         # Search for multiple CLI names.
         for name in self.cli_names:
@@ -195,7 +209,9 @@ class PackageManager:
         """
         if self.executable:
             # Invoke the manager.
-            output = self.run_cli(self.version_cli_options, force_exec=True)
+            output = self.run_cli(
+                self.version_cli_options, skip_globals=True, force_exec=True
+            )
 
             # Extract the version with the regex.
             if output:
@@ -254,15 +270,21 @@ class PackageManager:
         """Run a shell command, return the output and accumulate error messages.
 
         args is allowed to be a nested structure of iterables, in which case it will
-        be flatten, then each item within casted to strings.
+        be recursively flatten, and each item within casted to strings.
 
-        Internally reuse the run() method from the xbar plugin, but adds logs at the
-        appropriate level, removes ANSI escape codes, returns ready-to-use strings, and
-        takes --dry-run and --stop-on-error into account.
+        Running commands with that method:
+          * adds logs at the appropriate level
+          * removes ANSI escape codes from ``<stdout>`` and ``<stderr>``
+          * returns ready-to-use normalized strings (dedented and stripped)
+          * let ``--dry-run`` and ``--stop-on-error`` have effect on execution
+
+        ..todo:
+
+            Move ``--dry-run`` option and this method to click-extra?
         """
         # Casting to string helps serialize Path and Version objects.
         args = list(map(str, flatten(args)))
-        args_str = click.style(" ".join(args), fg="white")
+        args_str = theme.invoked_command(" ".join(args))
         cli_msg = f"{PROMPT}{args_str}"
 
         code = 0
@@ -277,10 +299,10 @@ class PackageManager:
 
         # Normalize messages.
         if error:
-            error = strip_ansi(error)
+            error = dedent(strip_ansi(error).strip())
             error = error if error else None
         if output:
-            output = strip_ansi(output)
+            output = dedent(strip_ansi(output).strip())
             output = output if output else None
 
         # Log <stdout> and <stderr> output.
@@ -302,13 +324,24 @@ class PackageManager:
 
         return output
 
-    def run_cli(self, *args, force_exec=False):
+    def run_cli(self, *args, skip_globals=False, force_exec=False):
         """Shortcut utility to the ``run`` method above, that is explicitly using the
         binary set by the ``cli_path`` property.
 
+        ``global_args`` are automaticcaly added before the provided args unless
+        ``prepend_global_args`` is ``False``. if ``skip_globals`` is ``True`` global arguments
+        are not added whatsoever to the list of provided ``args``.
+
         Also offer the possibility to force the execution and completion of the command
-        regardless of the instance --dry-run and --stop-on-error user options.
+        regardless of ``--dry-run`` and ``--stop-on-error`` user options.
         """
+        # Prepare the full list of CLI arguments.
+        if not skip_globals:
+            if self.prepend_global_args:
+                args = list(self.global_args) + list(args)
+            else:
+                args = list(args) + list(self.global_args)
+
         # Temporarily replace --dry-run and --stop-on-error user options with our own.
         if force_exec:
             user_options = (self.dry_run, self.stop_on_error)
