@@ -17,15 +17,16 @@
 
 import re
 
+from click_extra.logging import logger
+from click_extra.platform import LINUX, MACOS, WINDOWS
+
 from ..base import PackageManager
-from ..platform import LINUX, MACOS, WINDOWS
 from ..version import parse_version
-from . import logger
 
 
 class Gem(PackageManager):
 
-    platforms = frozenset([LINUX, MACOS, WINDOWS])
+    platforms = frozenset({LINUX, MACOS, WINDOWS})
 
     name = "Ruby Gems"
 
@@ -41,11 +42,10 @@ class Gem(PackageManager):
     """
 
     # Help mpm a little bit in its search for the `gem` binary.
-    cli_search_path = ["/usr/local/opt/ruby/bin/gem", "/usr/local/opt/ruby/bin"]
+    cli_search_path = ("/usr/local/opt/ruby/bin/gem", "/usr/local/opt/ruby/bin")
 
-    global_args = [
-        "--quiet",  # Silence command progress meter
-    ]
+    global_args = ("--quiet",)  # Silence command progress meter
+    prepend_global_args = False
 
     @property
     def installed(self):
@@ -75,7 +75,7 @@ class Gem(PackageManager):
         """
         installed = {}
 
-        output = self.run_cli("list", self.global_args)
+        output = self.run_cli("list")
 
         if output:
             regexp = re.compile(r"(\S+) \((.+)\)")
@@ -85,11 +85,9 @@ class Gem(PackageManager):
                     package_id, versions = match.groups()
                     # Guess latest installed version.
                     version = max(
-                        [
-                            parse_version(v)
-                            for v in re.compile(r",|default:| ").split(versions)
-                            if v
-                        ]
+                        parse_version(v)
+                        for v in re.compile(r",|default:| ").split(versions)
+                        if v
                     )
                     installed[package_id] = {
                         "id": package_id,
@@ -131,9 +129,7 @@ class Gem(PackageManager):
         if exact:
             search_arg.append("--exact")
 
-        output = self.run_cli(
-            "search", query, "--versions", search_arg, self.global_args
-        )
+        output = self.run_cli("search", query, "--versions", search_arg)
 
         if output:
             regexp = re.compile(
@@ -179,7 +175,9 @@ class Gem(PackageManager):
             12 gems installed
         """
         super().install(package_id)
-        return self.run_cli("install", "--user-install", self.global_args, package_id)
+        return self.run_cli(
+            "install", "--user-install", self.global_args, package_id, skip_globals=True
+        )
 
     @property
     def outdated(self):
@@ -199,7 +197,7 @@ class Gem(PackageManager):
         """
         outdated = {}
 
-        output = self.run_cli("outdated", self.global_args)
+        output = self.run_cli("outdated")
 
         if output:
             regexp = re.compile(r"(\S+) \((\S+) < (\S+)\)")
@@ -250,4 +248,4 @@ class Gem(PackageManager):
             Clean up complete
         """
         super().cleanup()
-        self.run_cli("cleanup", self.global_args)
+        self.run_cli("cleanup")
