@@ -15,18 +15,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-import os
 import re
-from pathlib import Path
-from shutil import which
 
 import simplejson as json
-from boltons.cacheutils import cachedproperty
+from click_extra.logging import logger
+from click_extra.platform import LINUX, MACOS
 
 from ..base import PackageManager
-from ..platform import LINUX, MACOS
 from ..version import parse_version
-from . import logger
 
 
 class Homebrew(PackageManager):
@@ -37,7 +33,7 @@ class Homebrew(PackageManager):
     commands.
     """
 
-    platforms = frozenset([LINUX, MACOS])
+    platforms = frozenset({LINUX, MACOS})
 
     # Vanilla brew and cask CLIs now shares the same version.
     # 2.7.0 is the first release to enforce the use of --cask option.
@@ -56,6 +52,8 @@ class Homebrew(PackageManager):
         Homebrew/homebrew-cask (git revision 5095b; last commit 2018-12-28)
     """
 
+    prepend_global_args = False
+
     def sync(self):
         """Fetch content of remote taps.
 
@@ -65,7 +63,7 @@ class Homebrew(PackageManager):
             Already up-to-date.
         """
         super().sync()
-        self.run_cli("update", "--quiet")
+        self.run_cli("update", "--quiet", skip_globals=True)
 
     @property
     def installed(self):
@@ -75,7 +73,7 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew list --formula --versions
+            ► brew list --versions --formula
             ack 2.14
             apg 2.2.3
             audacity (!) 2.1.2
@@ -90,7 +88,7 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew list --cask --versions
+            ► brew list --versions --cask
             aerial 1.2beta5
             android-file-transfer latest
             audacity (!) 2.1.2
@@ -111,7 +109,7 @@ class Homebrew(PackageManager):
         """
         installed = {}
 
-        output = self.run_cli("list", self.global_args, "--versions")
+        output = self.run_cli("list", "--versions")
 
         if output:
             regexp = re.compile(r"(\S+)( \(!\))? (.+)")
@@ -145,13 +143,13 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew search --formulae sed
+            ► brew search sed --formulae
             ==> Formulae
             gnu-sed ✔                    libxdg-basedir               minised
 
         .. code-block:: shell-session
 
-            ► brew search --cask sed
+            ► brew search sed --cask
             ==> Casks
             eclipse-dsl                       marsedit
             focused                           physicseditor
@@ -160,20 +158,20 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew search --formulae python
+            ► brew search python --formulae
             ==> Formulae
             app-engine-python   boost-python3   python ✔          python-yq
             boost-python        gst-python      python-markdown   python@3.8 ✔
 
         .. code-block:: shell-session
 
-            ► brew search --formulae "/^ssed$/"
+            ► brew search "/^ssed$/" --formulae
             ==> Formulae
             ssed
 
         .. code-block:: shell-session
 
-            ► brew search --formulae "/^sed$/"
+            ► brew search "/^sed$/" --formulae
             No formula or cask found for "/^sed$/".
             Closed pull requests:
             Merge ba7a794 (https://github.com/Homebrew/linuxbrew-core/pull/198)
@@ -193,7 +191,7 @@ class Homebrew(PackageManager):
         if exact:
             query = f"/^{query}$/"
 
-        output = self.run_cli("search", self.global_args, query)
+        output = self.run_cli("search", query)
 
         if output:
             regexp = re.compile(
@@ -218,7 +216,7 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew install --formula jpeginfo
+            ► brew install jpeginfo --formula
             ==> Downloading https://ghcr.io/core/jpeginfo/manifests/1.6.1_1-1
             ############################################################## 100.0%
             ==> Downloading https://ghcr.io/core/jpeginfo/blobs/sha256:27bb35884368b83
@@ -229,7 +227,7 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew install --cask pngyu
+            ► brew install pngyu --cask
             Updating Homebrew...
             ==> Downloading https://nukesaq.github.io/Pngyu/download/Pngyu_mac_101.zip
             ################################################################## 100.0%
@@ -239,7 +237,7 @@ class Homebrew(PackageManager):
 
         """
         super().install(package_id)
-        return self.run_cli("install", self.global_args, package_id)
+        return self.run_cli("install", package_id)
 
     @property
     def outdated(self):
@@ -247,7 +245,7 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew outdated --formula --json=v2 | jq
+            ► brew outdated --json=v2 --formula | jq
             {
               "formulae": [
                 {
@@ -274,7 +272,7 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew outdated --cask --json=v2 | jq
+            ► brew outdated --json=v2 --cask | jq
             {
               "formulae": [],
               "casks": [
@@ -293,7 +291,7 @@ class Homebrew(PackageManager):
 
         .. code-block:: shell-session
 
-            ► brew outdated --cask --json=v2 --greedy | jq
+            ► brew outdated --json=v2 --greedy --cask | jq
             {
               "formulae": [],
               "casks": [
@@ -328,7 +326,7 @@ class Homebrew(PackageManager):
         outdated = {}
 
         # Build up the list of CLI options.
-        options = [self.global_args, "--json=v2"]
+        options = ["--json=v2"]
         # Includes auto-update packages or not.
         if not self.ignore_auto_updates:
             options.append("--greedy")
@@ -421,13 +419,14 @@ class Homebrew(PackageManager):
         return cmd
 
     def cleanup(self):
-        """Scrub the cache, including latest version's downloads.
+        """Scrub the cache, including latest version's downloads. Also remove unused
+        dependencies.
 
         Downloads for all installed formulae and casks will not be deleted.
 
         .. code-block:: shell-session
 
-            ► brew cleanup -s
+            ► brew cleanup -s --prune=all
             Removing: ~/Library/Caches/Homebrew/node--1.bottle.tar.gz... (9MB)
             Warning: Skipping sdl2: most recent version 2.0.12_1 not installed
             Removing: ~/Library/Caches/Homebrew/Cask/aerial--1.8.1.zip... (5MB)
@@ -438,70 +437,48 @@ class Homebrew(PackageManager):
 
         More doc at: https://docs.brew.sh/Manpage#cleanup-options-formulacask
 
-        TODO: add autoremove command from brew 2.5.9
-        https://github.com/Homebrew/brew/pull/9047
+        .. code-block:: shell-session
 
-        ❯ brew autoremove
-        ==> Uninstalling 17 unneeded formulae:
-        atkmm
-        c-ares
-        cairomm
-        glibmm
-        gtkmm3
-        highlight
-        jansson
-        libmaxminddb
-        libsigc++@2
-        libsmi
-        lua
-        lua@5.1
-        nasm
-        nghttp2
-        openblas
-        pangomm
-        texi2html
-        Uninstalling /usr/local/Cellar/nghttp2/1.41.0_1... (26 files, 2.7MB)
-        Uninstalling /usr/local/Cellar/highlight/3.59... (558 files, 3.5MB)
+            ► brew autoremove
+            ==> Uninstalling 17 unneeded formulae:
+            gtkmm3
+            highlight
+            lua@5.1
+            nasm
+            nghttp2
+            texi2html
+            Uninstalling /usr/local/Cellar/nghttp2/1.41.0_1... (26 files, 2.7MB)
+            Uninstalling /usr/local/Cellar/highlight/3.59... (558 files, 3.5MB)
 
-        Warning: The following highlight configuration files have not been removed!
-        If desired, remove them manually with `rm -rf`:
-          /usr/local/etc/highlight
-          /usr/local/etc/highlight/filetypes.conf
-          /usr/local/etc/highlight/filetypes.conf.default
-        Uninstalling /usr/local/Cellar/gtkmm3/3.24.2_1... (1,903 files, 173.7MB)
-        Uninstalling /usr/local/Cellar/texi2html/5.0... (279 files, 6.2MB)
-        Uninstalling /usr/local/Cellar/lua@5.1/5.1.5_8... (22 files, 245.6KB)
-        Uninstalling /usr/local/Cellar/nasm/2.15.05... (29 files, 2.9MB)
-        Uninstalling /usr/local/Cellar/libsmi/0.5.0... (476 files, 20.1MB)
-        Uninstalling /usr/local/Cellar/openblas/0.3.12_1... (23 files, 120.2MB)
-        Uninstalling /usr/local/Cellar/libmaxminddb/1.4.3... (32 files, 164.3KB)
-        Uninstalling /usr/local/Cellar/jansson/2.13.1... (11 files, 169.0KB)
-        Uninstalling /usr/local/Cellar/c-ares/1.16.1_1... (84 files, 539.0KB)
-        Uninstalling /usr/local/Cellar/lua/5.3.5_1... (28 files, 274.5KB)
-        Uninstalling /usr/local/Cellar/pangomm/2.42.1_2... (353 files, 5.6MB)
-        Uninstalling /usr/local/Cellar/atkmm/2.28.0_2... (231 files, 5.1MB)
-        Uninstalling /usr/local/Cellar/glibmm/2.64.2... (1,736 files, 47.7MB)
-        Uninstalling /usr/local/Cellar/cairomm/1.12.2_1... (258 files, 3.9MB)
-        Uninstalling /usr/local/Cellar/libsigc++@2/2.10.4... (44 files, 1.3MB)
+            Warning: The following highlight configuration files have not been removed!
+            If desired, remove them manually with `rm -rf`:
+              /usr/local/etc/highlight
+              /usr/local/etc/highlight/filetypes.conf
+              /usr/local/etc/highlight/filetypes.conf.default
+            Uninstalling /usr/local/Cellar/gtkmm3/3.24.2_1... (1,903 files, 173.7MB)
+            Uninstalling /usr/local/Cellar/texi2html/5.0... (279 files, 6.2MB)
+            Uninstalling /usr/local/Cellar/lua@5.1/5.1.5_8... (22 files, 245.6KB)
+            Uninstalling /usr/local/Cellar/nasm/2.15.05... (29 files, 2.9MB)
 
         """
         super().cleanup()
-        self.run_cli("cleanup", "-s")
+        self.run_cli("autoremove", skip_globals=True)
+        self.run_cli("cleanup", "-s", "--prune=all", skip_globals=True)
 
 
 class Brew(Homebrew):
 
     name = "Homebrew Formulae"
-    cli_names = ["brew"]
+    cli_names = ("brew",)
 
-    global_args = ["--formula"]
+    global_args = ("--formula",)
 
 
 class Cask(Homebrew):
 
     # Casks are only available on macOS, not Linux.
-    platforms = frozenset([MACOS])
+    platforms = frozenset({MACOS})
     name = "Homebrew Cask"
-    cli_names = ["brew"]
+    cli_names = ("brew",)
 
-    global_args = ["--cask"]
+    global_args = ("--cask",)
