@@ -17,15 +17,16 @@
 
 import re
 
+from click_extra.logging import logger
+from click_extra.platform import MACOS
+
 from ..base import PackageManager
-from ..platform import MACOS
 from ..version import parse_version
-from . import logger
 
 
 class MAS(PackageManager):
 
-    platforms = frozenset([MACOS])
+    platforms = frozenset({MACOS})
 
     # 'mas search' output has been fixed in 1.6.1:
     # https://github.com/mas-cli/mas/pull/205
@@ -33,7 +34,7 @@ class MAS(PackageManager):
 
     name = "Mac AppStore"
 
-    version_cli_options = ["version"]
+    version_cli_options = ("version",)
     """
     .. code-block:: shell-session
 
@@ -55,7 +56,7 @@ class MAS(PackageManager):
         """
         installed = {}
 
-        output = self.run_cli(self.global_args, "list")
+        output = self.run_cli("list")
 
         if output:
             regexp = re.compile(r"(\d+) (.*) \((\S+)\)$")
@@ -95,7 +96,7 @@ class MAS(PackageManager):
                 f"Extended search not supported for {self.id}. Fallback to Fuzzy."
             )
 
-        output = self.run_cli(self.global_args, "search", query)
+        output = self.run_cli("search", query)
 
         if output:
             regexp = re.compile(
@@ -135,7 +136,7 @@ class MAS(PackageManager):
 
         """
         super().install(package_id)
-        return self.run_cli(self.global_args, "install", package_id)
+        return self.run_cli("install", package_id)
 
     @property
     def outdated(self):
@@ -153,7 +154,7 @@ class MAS(PackageManager):
         """
         outdated = {}
 
-        output = self.run_cli(self.global_args, "outdated")
+        output = self.run_cli("outdated")
 
         if output:
             regexp = re.compile(r"(\d+) (.*) \((\S+) -> (\S+)\)$")
@@ -179,7 +180,7 @@ class MAS(PackageManager):
         return outdated
 
     def upgrade_cli(self, package_id=None):
-        cmd = [self.cli_path, self.global_args, "upgrade"]
+        cmd = [self.cli_path, "upgrade"]
         if package_id:
             cmd.append(package_id)
         return cmd
