@@ -18,9 +18,9 @@
 import re
 
 import simplejson as json
+from click_extra.platform import LINUX, MACOS, WINDOWS
 
 from ..base import PackageManager
-from ..platform import LINUX, MACOS, WINDOWS
 from ..version import TokenizedString, parse_version
 
 
@@ -33,21 +33,21 @@ class Pip(PackageManager):
     Source: https://snarky.ca/why-you-should-use-python-m-pip/
     """
 
-    platforms = frozenset([MACOS, LINUX, WINDOWS])
+    platforms = frozenset({MACOS, LINUX, WINDOWS})
 
     requirement = "10.0.0"
 
     # Targets `python3` CLI first to allow for some systems (like macOS) to keep the
     # default `python` CLI tied to the Python 2.x ecosystem.
-    cli_names = ["python3", "python"]
+    cli_names = ("python3", "python")
 
-    global_args = [
+    global_args = (
         "-m",
         "pip",  # Canonical call to Python's pip module.
         "--no-color",  # Suppress colored output.
-    ]
+    )
 
-    version_cli_options = global_args + ["--version"]
+    version_cli_options = tuple(list(global_args) + ["--version"])
     version_regex = r"pip\s+(?P<version>\S+)"
     """
     .. code-block:: shell-session
@@ -96,9 +96,7 @@ class Pip(PackageManager):
 
         # --quiet is required here to silence warning and error messages
         # mangling the JSON content.
-        output = self.run_cli(
-            self.global_args, "list", "--format=json", "--verbose", "--quiet"
-        )
+        output = self.run_cli("list", "--format=json", "--verbose", "--quiet")
 
         if output:
             for package in json.loads(output):
@@ -140,7 +138,7 @@ class Pip(PackageManager):
         """
         matches = {}
 
-        output = self.run_cli(self.global_args, "search", query)
+        output = self.run_cli("search", query)
 
         if output:
             regexp = re.compile(
@@ -195,7 +193,7 @@ class Pip(PackageManager):
 
         """
         super().install(package_id)
-        return self.run_cli(self.global_args, "install", package_id)
+        return self.run_cli("install", package_id)
 
     @property
     def outdated(self):
@@ -261,7 +259,6 @@ class Pip(PackageManager):
         # --quiet is required here to silence warning and error messages
         # mangling the JSON content.
         output = self.run_cli(
-            self.global_args,
             "list",
             "--format=json",
             "--outdated",
