@@ -15,18 +15,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from click_extra.platform import LINUX
+
 from ..base import PackageManager
-from ..platform import LINUX
 from ..version import TokenizedString, parse_version
 
 
 class Snap(PackageManager):
 
-    platforms = frozenset([LINUX])
+    platforms = frozenset({LINUX})
 
     requirement = "2.0.0"
 
-    global_args = ["--color=never"]
+    global_args = ("--color=never",)
 
     version_regex = r"snap\s+(?P<version>\S+)"
     """
@@ -55,7 +56,7 @@ class Snap(PackageManager):
         """
         installed = {}
 
-        output = self.run_cli(self.global_args, "list")
+        output = self.run_cli("list")
 
         if output:
             for package in output.splitlines()[1:]:
@@ -81,7 +82,7 @@ class Snap(PackageManager):
         """
         matches = {}
 
-        output = self.run_cli(self.global_args, "find", query)
+        output = self.run_cli("find", query)
 
         if output:
 
@@ -121,7 +122,7 @@ class Snap(PackageManager):
 
         """
         super().install(package_id)
-        return self.run_cli(self.global_args, "install", package_id)
+        return self.run_cli("install", package_id)
 
     @property
     def outdated(self):
@@ -137,16 +138,14 @@ class Snap(PackageManager):
         """
         outdated = {}
 
-        output = self.run_cli(self.global_args, "refresh", "--list")
+        output = self.run_cli("refresh", "--list")
 
         if output and len(output.splitlines()) > 1:
             for package in output.splitlines()[1:]:
                 package_id = package.split()[0]
                 latest_version = package.split()[1]
                 installed_version = (
-                    self.run_cli(self.global_args, "list", package_id)
-                    .splitlines()[-1]
-                    .split()[1]
+                    self.run_cli("list", package_id).splitlines()[-1].split()[1]
                 )
                 outdated[package_id] = {
                     "id": package_id,
