@@ -19,7 +19,7 @@
 
 import pytest
 
-from ..managers import DEFAULT_MANAGER_IDS
+from ..pool import DEFAULT_MANAGER_IDS
 from .test_cli import CLISubCommandTests
 
 
