@@ -16,42 +16,35 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import pytest
+from click_extra.tests.conftest import destructive
 
-from ..managers import ALL_MANAGER_IDS, pool
-from .conftest import destructive
+from ..pool import ALL_MANAGER_IDS
 from .test_cli import CLISubCommandTests
 
 
 @pytest.fixture
 def subcmd():
-    """Seed common subcommand tests with a dummy file and content to allow the
-    CLI to not fail on required file input."""
-    return "--manager", "pip", "install", "arrow"
+    return "install", "arrow"
 
 
 class TestInstall(CLISubCommandTests):
+
+    strict_selection_match = False
+    """ Install sub-command try each user-selected manager until it find one providing
+    the package we seek to install, after which the process stop. This mean not all
+    managers will be called, so we allow the CLI output checks to partially match.
+    """
+
     def test_no_package_id(self, invoke):
         result = invoke("install")
         assert result.exit_code == 2
         assert not result.stdout
         assert "Error: Missing argument 'PACKAGE_ID'." in result.stderr
 
-    def test_no_manager(self, invoke):
-        result = invoke("install", "dummy")
-        assert result.exit_code == 2
-        assert not result.stdout
-        assert "critical: Only one package manager should be provided." in result.stderr
-
-    def test_multiple_manager(self, invoke):
-        result = invoke("--manager", "pip", "--manager", "npm", "install", "dummy")
-        assert result.exit_code == 2
-        assert not result.stdout
-        assert "critical: Only one package manager should be provided." in result.stderr
-
     PACKAGE_IDS = {
         "apm": "markdown-pdf",
-        "apt": "bat",
-        "apt-mint": "bat",
+        "apt": "wget",
+        "apt-mint": "exiftool",
         "brew": "jpeginfo",
         "cask": "pngyu",
         "choco": "ccleaner",
@@ -69,23 +62,15 @@ class TestInstall(CLISubCommandTests):
     assert set(PACKAGE_IDS) == set(ALL_MANAGER_IDS)
 
     @destructive
-    @pytest.mark.parametrize("mid,package_id", PACKAGE_IDS.items())
+    @pytest.mark.parametrize(
+        "mid,package_id", (pytest.param(*v, id=v[0]) for v in PACKAGE_IDS.items())
+    )
     def test_single_manager_install(self, invoke, mid, package_id):
         result = invoke("--manager", mid, "install", package_id)
-
-        if pool()[mid].available:
-            assert result.exit_code == 0
-            self.check_manager_selection(result, {mid})
-        else:
-            assert result.exit_code == 2
-            assert not result.stdout
-            assert "critical: A package manager must be provided" in result.stderr
+        assert result.exit_code == 0
+        self.check_manager_selection(result, {mid}, reference_set=ALL_MANAGER_IDS)
 
 
-destructive()(TestInstall.test_options)
-
-skip_multiple_manager = pytest.mark.skip(
-    reason="mpm install only support one manager at a time"
-)
-skip_multiple_manager(TestInstall.test_default_all_managers)
-skip_multiple_manager(TestInstall.test_manager_selection)
+destructive()(TestInstall.test_stats)
+destructive()(TestInstall.test_default_all_managers)
+destructive()(TestInstall.test_manager_selection)
