@@ -23,7 +23,7 @@ import pytest
 import simplejson as json
 from boltons.iterutils import same
 
-from ..managers import DEFAULT_MANAGER_IDS
+from ..pool import DEFAULT_MANAGER_IDS
 from .test_cli import CLISubCommandTests, CLITableTests
 
 
@@ -32,7 +32,7 @@ def subcmd():
     return "outdated"
 
 
-XBAR_KEYWORDS = {"shell"}.union({f"param{i}" for i in range(1, 10)})
+XBAR_KEYWORDS = frozenset({"shell"}.union({f"param{i}" for i in range(1, 10)}))
 
 
 class TestOutdated(CLISubCommandTests, CLITableTests):
