@@ -16,9 +16,9 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import pytest
+from click_extra.tests.conftest import destructive
 
-from ..managers import DEFAULT_MANAGER_IDS
-from .conftest import destructive
+from ..pool import DEFAULT_MANAGER_IDS
 from .test_cli import CLISubCommandTests
 
 
@@ -51,6 +51,6 @@ class TestUpgrade(CLISubCommandTests):
         self.check_manager_selection(result, {mid})
 
 
-destructive()(TestUpgrade.test_options)
+destructive()(TestUpgrade.test_stats)
 destructive()(TestUpgrade.test_default_all_managers)
 destructive()(TestUpgrade.test_manager_selection)
