@@ -19,16 +19,15 @@ import re
 from collections import Counter
 from pathlib import Path
 
-import pytest
 import simplejson as json
 import tomli
 from boltons.iterutils import flatten
+from click_extra.platform import OS_DEFINITIONS, os_label
+from click_extra.tests.conftest import unless_linux
 from yaml import Loader, load
 
 from ..labels import MANAGER_LABELS, MANAGER_PREFIX, PLATFORM_LABELS, PLATFORM_PREFIX
-from ..managers import ALL_MANAGER_IDS, pool
-from ..platform import OS_DEFINITIONS, os_label
-from .conftest import unless_linux
+from ..pool import ALL_MANAGER_IDS, pool
 
 """ Test all non-code artifacts depending on manager definitions.
 
@@ -49,13 +48,13 @@ def test_project_metadata():
     toml_path = Path(__file__).parent.joinpath("../../pyproject.toml").resolve()
     toml_config = tomli.loads(toml_path.read_text())
     # Check all managers are referenced in Python package keywords.
-    assert ALL_MANAGER_IDS.issubset(toml_config["tool"]["poetry"]["keywords"])
+    assert set(ALL_MANAGER_IDS).issubset(toml_config["tool"]["poetry"]["keywords"])
 
 
 def test_changelog():
-    content = PROJECT_ROOT.joinpath("changelog.rst").read_text()
+    content = PROJECT_ROOT.joinpath("changelog.md").read_text()
 
-    assert content.startswith("Changelog\n=========\n")
+    assert content.startswith("# Changelog\n")
 
     entry_pattern = re.compile(r"^\* \[(?P<category>[a-z,]+)\] (?P<entry>.+)")
     for line in content.splitlines():
@@ -66,7 +65,7 @@ def test_changelog():
             assert entry["category"]
             assert set(entry["category"].split(",")).issubset(
                 flatten(
-                    [ALL_MANAGER_IDS, OS_DEFINITIONS.keys(), "mpm", "bitbar", "xbar"]
+                    (ALL_MANAGER_IDS, OS_DEFINITIONS.keys(), "mpm", "bitbar", "xbar")
                 )
             )
 
