@@ -23,8 +23,8 @@ from ..version import Token, TokenizedString, parse_version
 
 
 def reverse_fixtures(table):
-    """Utility method to reverse a list of list."""
-    return list(map(list, map(reversed, table)))
+    """Utility method to reverse a tuple of tuples."""
+    return tuple(map(tuple, map(reversed, table)))
 
 
 @pytest.mark.parametrize("value", [0, 123, "0", "123", "abc", "ABC", "123abc"])
@@ -39,59 +39,59 @@ def test_token_unauthorized_instanciation(value):
 
 
 eq_values = [
-    [Token("2345"), Token("2345")],
-    [Token("2345"), Token(2345)],
-    [Token("02345"), Token(2345)],
-    [Token("02345"), "02345"],
-    [Token("2345"), 2345],
-    [Token("2345"), "2345"],
-    [Token("0"), "0"],
-    [Token("0"), 0],
-    [Token("000"), 0],
-    [Token("abc"), "abc"],
-    [Token("abc"), Token("abc")],
+    (Token("2345"), Token("2345")),
+    (Token("2345"), Token(2345)),
+    (Token("02345"), Token(2345)),
+    (Token("02345"), "02345"),
+    (Token("2345"), 2345),
+    (Token("2345"), "2345"),
+    (Token("0"), "0"),
+    (Token("0"), 0),
+    (Token("000"), 0),
+    (Token("abc"), "abc"),
+    (Token("abc"), Token("abc")),
 ]
 
 
 ne_values = [
-    [Token("2345"), Token("45")],
-    [Token("2345"), Token(45)],
-    [Token("2345"), Token(0)],
-    [Token("2345"), Token("0")],
-    [Token("2"), -2],
-    [Token("2"), 0],
-    [Token("abc"), "def"],
-    [Token("Z"), "z"],
-    [Token("acb"), 123],
+    (Token("2345"), Token("45")),
+    (Token("2345"), Token(45)),
+    (Token("2345"), Token(0)),
+    (Token("2345"), Token("0")),
+    (Token("2"), -2),
+    (Token("2"), 0),
+    (Token("abc"), "def"),
+    (Token("Z"), "z"),
+    (Token("acb"), 123),
 ]
 
 
 gt_values = [
-    [Token("9999"), Token("12")],
-    [Token("9999"), Token("000000099")],
-    [Token(9999), Token("12")],
-    [Token(9999), Token(12)],
-    [Token(9999), "0"],
-    [Token(9999), 0],
-    [Token(0), -2],
-    [Token("0"), -2],
-    [Token("abc"), -2],
-    [Token("abc"), "ab"],
-    [Token("a"), "Z"],
-    [Token("z"), "Z"],
-    [Token("a"), Token("Z")],
+    (Token("9999"), Token("12")),
+    (Token("9999"), Token("000000099")),
+    (Token(9999), Token("12")),
+    (Token(9999), Token(12)),
+    (Token(9999), "0"),
+    (Token(9999), 0),
+    (Token(0), -2),
+    (Token("0"), -2),
+    (Token("abc"), -2),
+    (Token("abc"), "ab"),
+    (Token("a"), "Z"),
+    (Token("z"), "Z"),
+    (Token("a"), Token("Z")),
 ]
 
 
 lt_values = [
-    [Token("12"), Token("9999")],
-    [Token("0000012"), Token("9999")],
-    [Token("12"), Token(9999)],
-    [Token(12), Token(9999)],
-    [Token("12"), 9999],
-    [Token("0"), 9999],
-    [Token("ab"), "abc"],
-    [Token("Z"), "z"],
+    (Token("12"), Token("9999")),
+    (Token("0000012"), Token("9999")),
+    (Token("12"), Token(9999)),
+    (Token(12), Token(9999)),
+    (Token("12"), 9999),
+    (Token("0"), 9999),
+    (Token("ab"), "abc"),
+    (Token("Z"), "z"),
 ]
 
 
@@ -134,13 +134,15 @@ def test_token_hash():
 
 
 @pytest.mark.parametrize(
-    "value", [0, 123, -1, "0", "1.2.3", "abc", "A-B-C", "123   a bc \n"]
+    "value", (0, 123, -1, "0", "1.2.3", "abc", "A-B-C", "123   a bc \n")
 )
 def test_tokenized_string_allowed_instanciation(value):
     TokenizedString(value)
 
 
-@pytest.mark.parametrize("value", [None, 1.0, [1, 2, 3]])
+@pytest.mark.parametrize(
+    "value", (None, 1.0, [1, 2, 3], (1, 2, 3), {1, 2, 3}, {"a": 1, "b": 2})
+)
 def test_tokenized_string_unauthorized_instanciation(value):
     with pytest.raises(TypeError):
         TokenizedString(value)
@@ -165,47 +167,47 @@ def test_tokenized_string_idempotent_instanciation():
     assert tok1 == tok2
 
 
-version_list = [
-    ["r2917_1", ("r", 2917, 1)],
-    [" r     29   \n  17   1 x  ", ("r", 29, 17, 1, "x")],
-    ["2020.03.24", (2020, 3, 24)],
-    ["4.2.1-5666.3", (4, 2, 1, 5666, 3)],
-    ["4.2.1-5666..3", (4, 2, 1, 5666, 3)],
-    ["4.2.1-5666.3.", (4, 2, 1, 5666, 3)],
-    [".4.2.1-5666.3", (4, 2, 1, 5666, 3)],
-    ["4.2.1--5666.3", (4, 2, 1, 5666, 3)],
-    ["4.2.1-#-5666.3", (4, 2, 1, 5666, 3)],
-    ["4.2.1-ABC-5666.3", (4, 2, 1, "abc", 5666, 3)],
-    [
+version_list = (
+    ("r2917_1", ("r", 2917, 1)),
+    (" r     29   \n  17   1 x  ", ("r", 29, 17, 1, "x")),
+    ("2020.03.24", (2020, 3, 24)),
+    ("4.2.1-5666.3", (4, 2, 1, 5666, 3)),
+    ("4.2.1-5666..3", (4, 2, 1, 5666, 3)),
+    ("4.2.1-5666.3.", (4, 2, 1, 5666, 3)),
+    (".4.2.1-5666.3", (4, 2, 1, 5666, 3)),
+    ("4.2.1--5666.3", (4, 2, 1, 5666, 3)),
+    ("4.2.1-#-5666.3", (4, 2, 1, 5666, 3)),
+    ("4.2.1-ABC-5666.3", (4, 2, 1, "abc", 5666, 3)),
+    (
         "4.2.1-éèàçÇÉÈ²³¼ÀÁÂÃÄ—ÅËÍÑÒÖÜÝåïš™-5666.3",
         (4, 2, 1, "eeaccee", 231, 4, "aaaaae", "ainooeueyastm", 5666, 3),
-    ],
-    ["1.3_1", (1, 3, 1)],
-    ["2.40.20161221.0239", (2, 40, 20161221, 239)],
-    ["latest", ("latest",)],
-    ["1.2beta5", (1, 2, "beta", 5)],
-    ["2.8.18-x86_64", (2, 8, 18, "x", 86, 64)],
-    ["1.8.0_112-b16", (1, 8, 0, 112, "b", 16)],
-    ["3.6.9_build_4685", (3, 6, 9, "build", 4685)],
-    ["1.8.6-124-g6cd4c31", (1, 8, 6, 124, "g", 6, "cd", 4, "c", 31)],
-    ["0.9999999", (0, 9999999)],
-    ["0.0.0", (0, 0, 0)],
-    ["1.0+git71+c79e264-r0", (1, 0, "git", 71, "c", 79, "e", 264, "r", 0)],
-    ["20190718-r0", (20190718, "r", 0)],
-    ["0.0.0-development", (0, 0, 0, "development")],
-    ["v0.9.4.3", ("v", 0, 9, 4, 3)],
-    ["6.0.1-0ubuntu1", (6, 0, 1, 0, "ubuntu", 1)],
-    ["4.6.0+git+20160126-2", (4, 6, 0, "git", 20160126, 2)],
-    ["1:5.25-2ubuntu1", (1, 5, 25, 2, "ubuntu", 1)],
-    ["1.18.4ubuntu1.1", (1, 18, 4, "ubuntu", 1, 1)],
-    ["20160104ubuntu1", (20160104, "ubuntu", 1)],
-    ["3.113+nmu3ubuntu4", (3, 113, "nmu", 3, "ubuntu", 4)],
-    [
+    ),
+    ("1.3_1", (1, 3, 1)),
+    ("2.40.20161221.0239", (2, 40, 20161221, 239)),
+    ("latest", ("latest",)),
+    ("1.2beta5", (1, 2, "beta", 5)),
+    ("2.8.18-x86_64", (2, 8, 18, "x", 86, 64)),
+    ("1.8.0_112-b16", (1, 8, 0, 112, "b", 16)),
+    ("3.6.9_build_4685", (3, 6, 9, "build", 4685)),
+    ("1.8.6-124-g6cd4c31", (1, 8, 6, 124, "g", 6, "cd", 4, "c", 31)),
+    ("0.9999999", (0, 9999999)),
+    ("0.0.0", (0, 0, 0)),
+    ("1.0+git71+c79e264-r0", (1, 0, "git", 71, "c", 79, "e", 264, "r", 0)),
+    ("20190718-r0", (20190718, "r", 0)),
+    ("0.0.0-development", (0, 0, 0, "development")),
+    ("v0.9.4.3", ("v", 0, 9, 4, 3)),
+    ("6.0.1-0ubuntu1", (6, 0, 1, 0, "ubuntu", 1)),
+    ("4.6.0+git+20160126-2", (4, 6, 0, "git", 20160126, 2)),
+    ("1:5.25-2ubuntu1", (1, 5, 25, 2, "ubuntu", 1)),
+    ("1.18.4ubuntu1.1", (1, 18, 4, "ubuntu", 1, 1)),
+    ("20160104ubuntu1", (20160104, "ubuntu", 1)),
+    ("3.113+nmu3ubuntu4", (3, 113, "nmu", 3, "ubuntu", 4)),
+    (
         "13.0.2,8:d4173c853231432f001e99d882",
         (13, 0, 2, 8, "d", 4173, "c", 853231432, "f", 1, "e", 99, "d", 882),
-    ],
-    ["1.01+20150706hgc3698e0+dfsg-2", (1, 1, 20150706, "hgc", 3698, "e", 0, "dfsg", 2)],
-]
+    ),
+    ("1.01+20150706hgc3698e0+dfsg-2", (1, 1, 20150706, "hgc", 3698, "e", 0, "dfsg", 2)),
+)
 
 
 @pytest.mark.parametrize("v_string,v_tuple", version_list)
@@ -213,25 +215,25 @@ def test_version_tokenizer(v_string, v_tuple):
     assert TokenizedString(v_string) == v_tuple
 
 
-compared_gt = [
-    ["2.0", "1.0"],
-    ["0.1", "0"],
-    ["0.1", "0.0"],
-    ["0.1", "0.0.0.0.0"],
-    # ["0.1", "0.beta2"],
-    ["2.0", "1.0"],
-    ["2.0", "1"],
-    ["3.1.10", "3.1.9"],
-    # ["6.2", "6.2.0"],
-    # ["9.52", "9d"],
-    ["8.2p1_1", "8.2p1"],
-    # ["3.7.7", "3.7-beta2_1"],
-    # ["2.1.1", "2.1.1-git-23hfb2-foobar"],
-    [20200313, 20190801],
-    ["2020.03.24", "2019.11.28"],
-    # ["14.0.1,7:664493ef4a6946b186ff29eb326336a2",
-    #  "14,36:076bab302c7b4508975440c56f6cc26a"],
-]
+compared_gt = (
+    ("2.0", "1.0"),
+    ("0.1", "0"),
+    ("0.1", "0.0"),
+    ("0.1", "0.0.0.0.0"),
+    # ("0.1", "0.beta2"),
+    ("2.0", "1.0"),
+    ("2.0", "1"),
+    ("3.1.10", "3.1.9"),
+    # ("6.2", "6.2.0"),
+    # ("9.52", "9d"),
+    ("8.2p1_1", "8.2p1"),
+    # ("3.7.7", "3.7-beta2_1"),
+    # ("2.1.1", "2.1.1-git-23hfb2-foobar"),
+    (20200313, 20190801),
+    ("2020.03.24", "2019.11.28"),
+    # ("14.0.1,7:664493ef4a6946b186ff29eb326336a2",
+    #  "14,36:076bab302c7b4508975440c56f6cc26a"),
+)
 
 
 @pytest.mark.parametrize("ver1,ver2", compared_gt)
@@ -248,7 +250,7 @@ def test_version_comparison_lt(ver1, ver2):
 
 @pytest.mark.parametrize(
     "sequence",
-    [
+    (
         [
             "r0",
             "r1",
@@ -262,7 +264,7 @@ def test_version_comparison_lt(ver1, ver2):
             "r02920_20",
             "r02920_021",
         ],
-    ],
+    ),
 )
 def test_version_sorting(sequence):
     sorted_version = list(map(TokenizedString, sequence))
