@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # <xbar.title>Meta Package Manager</xbar.title>
-# <xbar.version>v4.5.0</xbar.version>
+# <xbar.version>v4.9.1</xbar.version>
 # <xbar.author>Kevin Deldycke</xbar.author>
 # <xbar.author.github>kdeldycke</xbar.author.github>
 # <xbar.desc>List outdated packages and manage upgrades.</xbar.desc>
@@ -23,6 +23,7 @@ Python 3.7.3 or newer.
 
 import json
 import os
+import re
 from operator import itemgetter
 from subprocess import PIPE, Popen
 
@@ -70,13 +71,13 @@ def fix_environment():
     preference order would equate to Homebrew, Macports, then system.
     """
     os.environ["PATH"] = ":".join(
-        [
+        (
             "/usr/local/bin",
             "/usr/local/sbin",
             "/opt/local/bin",
             "/opt/local/sbin",
             os.environ.get("PATH", ""),
-        ]
+        )
     )
 
 
@@ -97,12 +98,12 @@ def run(*args):
 
 def pp(params):
     """Print all parameters separated by a pipe. Ignore empty items."""
-    print(" | ".join([p for p in params if p]))
+    print(" | ".join((p for p in params if p)))
 
 
 def print_error_header():
     """Generic header for blockng error."""
-    pp(["❌", "dropdown=false"])
+    pp(("❌", "dropdown=false"))
     print("---")
 
 
@@ -169,7 +170,12 @@ def print_menu():
     if not code and not error:
         mpm_installed = True
         # Is mpm too old?
-        mpm_version = tuple(map(int, output.split()[1].split(".")))
+        version_string = (
+            re.compile(r".*\s+(?P<version>[0-9\.]+)$", re.MULTILINE)
+            .search(output)
+            .groupdict()["version"]
+        )
+        mpm_version = tuple(map(int, version_string.split(".")))
         if mpm_version >= MPM_MIN_VERSION:
             mpm_up_to_date = True
 
@@ -187,7 +193,7 @@ def print_menu():
                 "param2=pip",
                 "param3=install",
                 "param4=--upgrade",
-                f"param5=meta-package-manager>={min_version_str}",
+                f'param5="meta-package-manager>={min_version_str}"',
                 "terminal=true",
                 "refresh=true",
                 FONTS["error"],
@@ -214,8 +220,8 @@ def print_menu():
     managers = sorted(json.loads(output).values(), key=itemgetter("name"))
 
     # Print menu bar icon with number of available upgrades.
-    total_outdated = sum([len(m["packages"]) for m in managers])
-    total_errors = sum([len(m.get("errors", [])) for m in managers])
+    total_outdated = sum((len(m["packages"]) for m in managers))
+    total_errors = sum((len(m.get("errors", [])) for m in managers))
     pp(
         [
             "↑{}{}".format(
@@ -230,8 +236,8 @@ def print_menu():
 
     if SUBMENU_LAYOUT:
         # Compute maximal manager's name length.
-        label_max_length = max([len(m["name"]) for m in managers])
-        max_outdated = max([len(m["packages"]) for m in managers])
+        label_max_length = max(len(m["name"]) for m in managers)
+        max_outdated = max(len(m["packages"]) for m in managers)
         print("---")
 
     for manager in managers:
